@@ -197,15 +197,16 @@ class FeatureSelector:
 
     Parameters
     ----------
-        data : pd.DataFrame
+        X : pd.DataFrame
             A dataset with observations in the rows and features in the columns
 
-        labels : array or series, default = None
+        y : array or series, default = None
             Array of labels for training the machine learning model to find feature importances.
             These can be either binary labels (if task is 'classification') or continuous targets
             (if task is 'regression').
             If no labels are provided, then the feature importance based methods are not available.
-        weight : pd.Series or np.array.
+
+        sample_weight : pd.Series or np.array.
             Sample weights, if any
 
     Attributes
@@ -424,17 +425,17 @@ class FeatureSelector:
     hv.save(feat_imp, outpath+"feat_imp_TPLMD_freq.html")
     """
 
-    def __init__(self, data, labels=None, weight=None):
+    def __init__(self, X, y=None, sample_weight=None):
 
         # Dataset and optional training labels
-        self.data = data
-        self.labels = labels
-        self.weight = weight
+        self.data = X
+        self.labels = y
+        self.weight = sample_weight
 
-        if labels is None:
+        if y is None:
             print('No labels provided. Feature importance based methods are not available.')
 
-        self.base_features = list(data.columns)
+        self.base_features = list(self.data.columns)
         self.cat_features = None
 
         # Dataframes recording information about features to remove
@@ -566,9 +567,12 @@ class FeatureSelector:
         """
 
         col_names = list(self.data)
-        cat_var_index = [i for i, x in enumerate(self.data.dtypes.tolist()) if
-                         isinstance(x, pd.CategoricalDtype) or x == 'object']
-        char_cols = [x for i, x in enumerate(col_names) if i in cat_var_index]
+
+        char_cols = list(set(list(self.data.columns)) - set(list(self.data.select_dtypes(include=[np.number]))))
+
+        # cat_var_index = [i for i, x in enumerate(self.data.dtypes.tolist()) if
+        #                  isinstance(x, pd.CategoricalDtype) or x == 'object']
+        # char_cols = [x for i, x in enumerate(col_names) if i in cat_var_index]
 
         unique_counts = self.data[char_cols].nunique()
         self.cardinality_stats = pd.DataFrame(unique_counts).rename(columns={'index': 'feature', 0: 'nunique'})
@@ -586,17 +590,21 @@ class FeatureSelector:
             len(self.ops['high_cardinality']), max_card)
         )
 
-    def encode_cat_var(self, df=None, col_excl=None):
+    def encode_cat_var(self, df=None, col_excl=None, return_cat=False):
         """
         Categorical encoding (as integer). Automatically detect the non-numerical columns,
         save the index and name of those columns, encode them as integer,
         save the direct and inverse mappers as dictionaries.
         Return the data-set with the encoded columns with a data type either int or pandas categorical.
 
+
         :param df: pd.DataFrame
             the dataset
         :param col_excl: list of str, default=None
             the list of columns names not being encoded (e.g. the ID column)
+        :param return_cat: Boolean, default=False
+            wether or not return pandas categorical (if false --> integer)
+
         :return:
          df: pd.DataFrame
             the dataframe with encoded columns
@@ -607,7 +615,7 @@ class FeatureSelector:
         else:
             is_external_data = True
 
-        df, cat_var_df, inv_mapper, mapper = cat_var(df, col_excl=col_excl, return_cat=True)
+        df, cat_var_df, inv_mapper, mapper = cat_var(df, col_excl=col_excl, return_cat=return_cat)
 
         self.cat_var_df = cat_var_df
         self.mapper = inv_mapper
